gfks.HelpText (Help Text) — amici1

# `gfks.HelpText` (Help Text)

HelpText(id, content_type, field, help_text)

Master tables : gfks.HelpTexts (Help Texts)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Model (content_type) : See `<django.db.models.fields.related.ForeignKey: content_type>`.

- Field (field) : See `<django.db.models.fields.CharField: field>`.

- HelpText (help_text) : See `<lino.core.fields.RichTextField: help_text>`.

- Verbose name (verbose_name) : See `lino.modlib.gfks.models.HelpText.verbose_name`.

- Name (name_column) : See `lino.modlib.gfks.models.HelpText.name_column`.

- (None) (navigation_panel) : See `lino.modlib.gfks.models.HelpText.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.gfks.models.HelpText.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
content_type | Model |
field | Field |
help_text | HelpText |
verbose_name | Verbose name |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |